# yagni

[![Docs status](https://readthedocs.org/projects/yagni/badge/?version=latest&style=plastic)](https://yagni.readthedocs.io)

You are probably gonna need it: a collection of useful Python utilities aggregated over many years of development.

Docs: [https://yagni.readthedocs.io](https://yagni.readthedocs.io)
